/****************************************************************************
** Meta object code from reading C++ file 'klocalizedcontext.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../ki18n-6.26.0/src/i18n/klocalizedcontext.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'klocalizedcontext.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17KLocalizedContextE_t {};
} // unnamed namespace

template <> constexpr inline auto KLocalizedContext::qt_create_metaobjectdata<qt_meta_tag_ZN17KLocalizedContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KLocalizedContext",
        "translationDomainChanged",
        "",
        "translationDomain",
        "i18n",
        "message",
        "QVariant",
        "param1",
        "param2",
        "param3",
        "param4",
        "param5",
        "param6",
        "param7",
        "param8",
        "param9",
        "param10",
        "i18nc",
        "context",
        "i18np",
        "singular",
        "plural",
        "i18ncp",
        "i18nd",
        "domain",
        "i18ndc",
        "i18ndp",
        "i18ndcp",
        "xi18n",
        "xi18nc",
        "xi18np",
        "xi18ncp",
        "xi18nd",
        "xi18ndc",
        "xi18ndp",
        "xi18ndcp"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'translationDomainChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'i18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(4, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
            { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 }, { 0x80000000 | 6, 16 },
        }}),
        // Method 'i18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
            { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'i18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
            { 0x80000000 | 6, 14 },
        }}),
        // Method 'i18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
        }}),
        // Method 'i18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
        }}),
        // Method 'i18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'i18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 },
        }}),
        // Method 'i18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &) const>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
        }}),
        // Method 'i18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &) const>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
        }}),
        // Method 'i18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &) const>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'i18n'
        QtMocHelpers::MethodData<QString(const QString &) const>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Method 'i18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(17, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 }, { 0x80000000 | 6, 16 },
        }}),
        // Method 'i18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'i18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'i18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 },
        }}),
        // Method 'i18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
        }}),
        // Method 'i18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'i18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'i18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 },
        }}),
        // Method 'i18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &) const>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
        }}),
        // Method 'i18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &) const>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'i18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &) const>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 },
        }}),
        // Method 'i18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(19, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 }, { 0x80000000 | 6, 16 },
        }}),
        // Method 'i18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'i18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'i18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 },
        }}),
        // Method 'i18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
        }}),
        // Method 'i18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'i18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'i18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 },
        }}),
        // Method 'i18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &) const>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
        }}),
        // Method 'i18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &) const>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'i18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &) const>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Method 'i18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(22, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
            { 0x80000000 | 6, 16 },
        }}),
        // Method 'i18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'i18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'i18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
        }}),
        // Method 'i18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 },
        }}),
        // Method 'i18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'i18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'i18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
        }}),
        // Method 'i18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &) const>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 },
        }}),
        // Method 'i18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &) const>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'i18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &) const>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Method 'i18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(23, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 }, { 0x80000000 | 6, 16 },
        }}),
        // Method 'i18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'i18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'i18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 },
        }}),
        // Method 'i18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
        }}),
        // Method 'i18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'i18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'i18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 },
        }}),
        // Method 'i18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &) const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
        }}),
        // Method 'i18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &) const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'i18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &) const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 },
        }}),
        // Method 'i18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(25, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
            { 0x80000000 | 6, 16 },
        }}),
        // Method 'i18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'i18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'i18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
        }}),
        // Method 'i18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 },
        }}),
        // Method 'i18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'i18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'i18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
        }}),
        // Method 'i18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &) const>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 },
        }}),
        // Method 'i18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &) const>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'i18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &) const>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 },
        }}),
        // Method 'i18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(26, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
            { 0x80000000 | 6, 16 },
        }}),
        // Method 'i18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'i18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'i18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
        }}),
        // Method 'i18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 },
        }}),
        // Method 'i18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'i18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'i18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
        }}),
        // Method 'i18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &) const>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 },
        }}),
        // Method 'i18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &) const>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'i18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &) const>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Method 'i18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(27, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
            { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
            { 0x80000000 | 6, 15 }, { 0x80000000 | 6, 16 },
        }}),
        // Method 'i18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
            { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
            { 0x80000000 | 6, 15 },
        }}),
        // Method 'i18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
            { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'i18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
            { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
        }}),
        // Method 'i18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
            { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
        }}),
        // Method 'i18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
            { 0x80000000 | 6, 11 },
        }}),
        // Method 'i18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'i18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
        }}),
        // Method 'i18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &) const>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
        }}),
        // Method 'i18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &) const>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 },
        }}),
        // Method 'i18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &) const>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Method 'xi18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(28, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
            { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 }, { 0x80000000 | 6, 16 },
        }}),
        // Method 'xi18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
            { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'xi18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
            { 0x80000000 | 6, 14 },
        }}),
        // Method 'xi18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
        }}),
        // Method 'xi18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
        }}),
        // Method 'xi18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'xi18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
            { 0x80000000 | 6, 10 },
        }}),
        // Method 'xi18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &, const QVariant &) const>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
        }}),
        // Method 'xi18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &, const QVariant &) const>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
        }}),
        // Method 'xi18n'
        QtMocHelpers::MethodData<QString(const QString &, const QVariant &) const>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'xi18n'
        QtMocHelpers::MethodData<QString(const QString &) const>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Method 'xi18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(29, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 }, { 0x80000000 | 6, 16 },
        }}),
        // Method 'xi18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(29, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'xi18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(29, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'xi18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(29, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 },
        }}),
        // Method 'xi18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(29, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
        }}),
        // Method 'xi18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(29, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'xi18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(29, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'xi18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(29, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 },
        }}),
        // Method 'xi18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &) const>(29, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
        }}),
        // Method 'xi18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &) const>(29, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'xi18nc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &) const>(29, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 5 },
        }}),
        // Method 'xi18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(30, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 }, { 0x80000000 | 6, 16 },
        }}),
        // Method 'xi18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'xi18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'xi18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 },
        }}),
        // Method 'xi18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
        }}),
        // Method 'xi18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'xi18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'xi18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 },
        }}),
        // Method 'xi18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &) const>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
        }}),
        // Method 'xi18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &) const>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'xi18np'
        QtMocHelpers::MethodData<QString(const QString &, const QString &) const>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Method 'xi18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(31, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
            { 0x80000000 | 6, 16 },
        }}),
        // Method 'xi18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'xi18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'xi18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
        }}),
        // Method 'xi18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 },
        }}),
        // Method 'xi18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'xi18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'xi18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
        }}),
        // Method 'xi18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &) const>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 },
        }}),
        // Method 'xi18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &) const>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'xi18ncp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &) const>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Method 'xi18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(32, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 }, { 0x80000000 | 6, 16 },
        }}),
        // Method 'xi18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'xi18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'xi18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
            { 0x80000000 | 6, 13 },
        }}),
        // Method 'xi18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
        }}),
        // Method 'xi18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'xi18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'xi18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
            { 0x80000000 | 6, 9 },
        }}),
        // Method 'xi18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &, const QVariant &) const>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
        }}),
        // Method 'xi18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QVariant &) const>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'xi18nd'
        QtMocHelpers::MethodData<QString(const QString &, const QString &) const>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 5 },
        }}),
        // Method 'xi18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(33, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
            { 0x80000000 | 6, 16 },
        }}),
        // Method 'xi18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'xi18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'xi18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
        }}),
        // Method 'xi18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 },
        }}),
        // Method 'xi18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'xi18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'xi18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
        }}),
        // Method 'xi18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &) const>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 },
        }}),
        // Method 'xi18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &) const>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'xi18ndc'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &) const>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 5 },
        }}),
        // Method 'xi18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(34, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
            { 0x80000000 | 6, 16 },
        }}),
        // Method 'xi18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Method 'xi18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'xi18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
        }}),
        // Method 'xi18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
            { 0x80000000 | 6, 12 },
        }}),
        // Method 'xi18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Method 'xi18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'xi18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
        }}),
        // Method 'xi18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &, const QVariant &) const>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 6, 8 },
        }}),
        // Method 'xi18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QVariant &) const>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'xi18ndp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &) const>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Method 'xi18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(35, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
            { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
            { 0x80000000 | 6, 15 }, { 0x80000000 | 6, 16 },
        }}),
        // Method 'xi18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
            { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
            { 0x80000000 | 6, 15 },
        }}),
        // Method 'xi18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
            { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 }, { 0x80000000 | 6, 14 },
        }}),
        // Method 'xi18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
            { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 }, { 0x80000000 | 6, 13 },
        }}),
        // Method 'xi18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
            { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
        }}),
        // Method 'xi18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
            { 0x80000000 | 6, 11 },
        }}),
        // Method 'xi18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &, const QVariant &) const>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Method 'xi18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &, const QVariant &) const>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 },
        }}),
        // Method 'xi18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &, const QVariant &) const>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
        }}),
        // Method 'xi18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &, const QVariant &) const>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { 0x80000000 | 6, 7 },
        }}),
        // Method 'xi18ndcp'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, const QString &) const>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'translationDomain'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KLocalizedContext, qt_meta_tag_ZN17KLocalizedContextE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KLocalizedContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KLocalizedContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KLocalizedContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17KLocalizedContextE_t>.metaTypes,
    nullptr
} };

void KLocalizedContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KLocalizedContext *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->translationDomainChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: { QString _r = _t->i18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->i18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->i18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->i18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->i18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->i18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->i18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->i18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->i18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->i18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->i18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->i18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->i18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->i18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->i18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: { QString _r = _t->i18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->i18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: { QString _r = _t->i18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->i18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { QString _r = _t->i18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 21: { QString _r = _t->i18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 22: { QString _r = _t->i18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 23: { QString _r = _t->i18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 24: { QString _r = _t->i18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 25: { QString _r = _t->i18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 26: { QString _r = _t->i18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 27: { QString _r = _t->i18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 28: { QString _r = _t->i18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 29: { QString _r = _t->i18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 30: { QString _r = _t->i18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 31: { QString _r = _t->i18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 32: { QString _r = _t->i18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 33: { QString _r = _t->i18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 34: { QString _r = _t->i18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[13])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 35: { QString _r = _t->i18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 36: { QString _r = _t->i18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 37: { QString _r = _t->i18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 38: { QString _r = _t->i18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 39: { QString _r = _t->i18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 40: { QString _r = _t->i18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 41: { QString _r = _t->i18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 42: { QString _r = _t->i18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 43: { QString _r = _t->i18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 44: { QString _r = _t->i18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 45: { QString _r = _t->i18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 46: { QString _r = _t->i18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 47: { QString _r = _t->i18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 48: { QString _r = _t->i18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 49: { QString _r = _t->i18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 50: { QString _r = _t->i18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 51: { QString _r = _t->i18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 52: { QString _r = _t->i18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 53: { QString _r = _t->i18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 54: { QString _r = _t->i18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 55: { QString _r = _t->i18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 56: { QString _r = _t->i18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[13])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 57: { QString _r = _t->i18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 58: { QString _r = _t->i18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 59: { QString _r = _t->i18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 60: { QString _r = _t->i18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 61: { QString _r = _t->i18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 62: { QString _r = _t->i18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 63: { QString _r = _t->i18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 64: { QString _r = _t->i18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 65: { QString _r = _t->i18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 66: { QString _r = _t->i18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 67: { QString _r = _t->i18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[13])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 68: { QString _r = _t->i18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 69: { QString _r = _t->i18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 70: { QString _r = _t->i18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 71: { QString _r = _t->i18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 72: { QString _r = _t->i18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 73: { QString _r = _t->i18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 74: { QString _r = _t->i18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 75: { QString _r = _t->i18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 76: { QString _r = _t->i18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 77: { QString _r = _t->i18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 78: { QString _r = _t->i18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[13])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[14])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 79: { QString _r = _t->i18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[13])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 80: { QString _r = _t->i18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 81: { QString _r = _t->i18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 82: { QString _r = _t->i18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 83: { QString _r = _t->i18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 84: { QString _r = _t->i18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 85: { QString _r = _t->i18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 86: { QString _r = _t->i18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 87: { QString _r = _t->i18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 88: { QString _r = _t->i18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 89: { QString _r = _t->xi18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 90: { QString _r = _t->xi18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 91: { QString _r = _t->xi18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 92: { QString _r = _t->xi18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 93: { QString _r = _t->xi18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 94: { QString _r = _t->xi18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 95: { QString _r = _t->xi18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 96: { QString _r = _t->xi18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 97: { QString _r = _t->xi18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 98: { QString _r = _t->xi18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 99: { QString _r = _t->xi18n((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 100: { QString _r = _t->xi18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 101: { QString _r = _t->xi18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 102: { QString _r = _t->xi18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 103: { QString _r = _t->xi18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 104: { QString _r = _t->xi18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 105: { QString _r = _t->xi18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 106: { QString _r = _t->xi18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 107: { QString _r = _t->xi18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 108: { QString _r = _t->xi18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 109: { QString _r = _t->xi18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 110: { QString _r = _t->xi18nc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 111: { QString _r = _t->xi18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 112: { QString _r = _t->xi18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 113: { QString _r = _t->xi18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 114: { QString _r = _t->xi18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 115: { QString _r = _t->xi18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 116: { QString _r = _t->xi18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 117: { QString _r = _t->xi18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 118: { QString _r = _t->xi18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 119: { QString _r = _t->xi18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 120: { QString _r = _t->xi18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 121: { QString _r = _t->xi18np((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 122: { QString _r = _t->xi18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[13])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 123: { QString _r = _t->xi18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 124: { QString _r = _t->xi18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 125: { QString _r = _t->xi18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 126: { QString _r = _t->xi18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 127: { QString _r = _t->xi18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 128: { QString _r = _t->xi18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 129: { QString _r = _t->xi18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 130: { QString _r = _t->xi18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 131: { QString _r = _t->xi18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 132: { QString _r = _t->xi18ncp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 133: { QString _r = _t->xi18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 134: { QString _r = _t->xi18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 135: { QString _r = _t->xi18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 136: { QString _r = _t->xi18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 137: { QString _r = _t->xi18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 138: { QString _r = _t->xi18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 139: { QString _r = _t->xi18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 140: { QString _r = _t->xi18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 141: { QString _r = _t->xi18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 142: { QString _r = _t->xi18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 143: { QString _r = _t->xi18nd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 144: { QString _r = _t->xi18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[13])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 145: { QString _r = _t->xi18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 146: { QString _r = _t->xi18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 147: { QString _r = _t->xi18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 148: { QString _r = _t->xi18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 149: { QString _r = _t->xi18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 150: { QString _r = _t->xi18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 151: { QString _r = _t->xi18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 152: { QString _r = _t->xi18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 153: { QString _r = _t->xi18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 154: { QString _r = _t->xi18ndc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 155: { QString _r = _t->xi18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[13])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 156: { QString _r = _t->xi18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 157: { QString _r = _t->xi18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 158: { QString _r = _t->xi18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 159: { QString _r = _t->xi18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 160: { QString _r = _t->xi18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 161: { QString _r = _t->xi18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 162: { QString _r = _t->xi18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 163: { QString _r = _t->xi18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 164: { QString _r = _t->xi18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 165: { QString _r = _t->xi18ndp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 166: { QString _r = _t->xi18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[13])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[14])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 167: { QString _r = _t->xi18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[13])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 168: { QString _r = _t->xi18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 169: { QString _r = _t->xi18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 170: { QString _r = _t->xi18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 171: { QString _r = _t->xi18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 172: { QString _r = _t->xi18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 173: { QString _r = _t->xi18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 174: { QString _r = _t->xi18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 175: { QString _r = _t->xi18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 176: { QString _r = _t->xi18ndcp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KLocalizedContext::*)(const QString & )>(_a, &KLocalizedContext::translationDomainChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->translationDomain(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTranslationDomain(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KLocalizedContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KLocalizedContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KLocalizedContextE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KLocalizedContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 177)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 177;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 177)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 177;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KLocalizedContext::translationDomainChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
